@@ -1,9 +1,10 @@
 """Utilizario de funciones usadas en los procesos de robotizacion
    con Python."""
 
-__version__ = "1.24"
+__version__ = "1.25"
 __author__ = "Jonathan Bolo"
 
+from ctypes.wintypes import PUINT
 import os, re, shutil
 import pysftp as sftp
 import logging
@@ -33,7 +34,7 @@ from functools import wraps
 import time
 
 from os import PathLike
-from typing import Iterator, Union, Iterable
+from typing import Iterator, Union, Iterable, List
 
 from pathlib import Path, PurePosixPath
 
@@ -111,7 +112,7 @@ def upload_file_sftp(filename:StrOrPathList,
             server.get_channel().settimeout(100000.0)
 
             try:
-                destine_path = PurePosixPath(destine_path)
+                destine_path = PurePosixPath(destine_path).as_posix()
             except:
                 raise Exception("Destino incorrecto")
             
@@ -131,7 +132,10 @@ def upload_file_sftp(filename:StrOrPathList,
                 
                 for i in lista_archivos:
                     log.debug ("Subiendo archivo: " + str(i))
-                    server.put(i, destine_path / i.name)
+                    server.put(
+                        i, 
+                        (PurePosixPath(destine_path) / i.name).as_posix())
+                    
             else:
                 try:
                     filename = Path(filename)
@@ -151,7 +155,9 @@ def upload_file_sftp(filename:StrOrPathList,
                         flag_exists = True
                         filename_local = dir_local / file
                         log.debug ("Subiendo archivo: " + str(filename_local))
-                        server.put(filename_local, destine_path / file)
+                        server.put(
+                            filename_local, 
+                            (PurePosixPath(destine_path) / file).as_posix())
                 
                 if not flag_exists:
                     raise Exception("No se encontró coincidencias para: " + 
@@ -184,22 +190,22 @@ def makedir_sftp(sftp_path:StrOrPath,
             server.get_channel().settimeout(100000.0)
             
             try:
-                sftp_path = PurePosixPath(sftp_path)
+                sftp_path = PurePosixPath(sftp_path).as_posix()
             except:
                 raise Exception("Directorio definido erroneo.")
 
-            log.info("Inicio creacion directorio:" + str(sftp_path))
+            log.info("Inicio creacion directorio:" + sftp_path)
 
             if recursive:
 
-                folder_list = str(sftp_path).split("/")
+                folder_list = sftp_path.split("/")
 
                 print(folder_list)
 
                 ini = 0
                 ini_dir = ""
 
-                if str(sftp_path)[0:1] == "/":
+                if sftp_path[0:1] == "/":
                     log.info("Trabajando con directorio absoluto '/' ")
                     ini = 1
                     ini_dir = "/"
@@ -231,11 +237,11 @@ def makedir_sftp(sftp_path:StrOrPath,
 
                 if not exists:
                     log.info("Creando directorio no recursivo:" + 
-                             str(sftp_path))
+                             sftp_path)
                     server.mkdir(sftp_path, mode)
                 else:
                     log.info("Directorio no recursivo ya existe:" + 
-                             str(sftp_path))
+                             sftp_path)
 
 def list_sftp(sftp_path:StrOrPath, 
               credentials={}, 
@@ -272,7 +278,7 @@ def list_sftp(sftp_path:StrOrPath,
             server.get_channel().settimeout(100000.0)
 
             try:
-                sftp_path = PurePosixPath(sftp_path)
+                sftp_path = PurePosixPath(sftp_path).as_posix()
             except:
                 raise Exception("Ruta origen erronea.")
             
@@ -316,7 +322,8 @@ def remove_sftp(list_files_sftp:StrOrPathList,
             for file in list_files_sftp:
                 try:
                     log.info("Borrando archivo: " + file)
-                    server.remove(file)
+                    p_file = PurePosixPath(file).as_posix()
+                    server.remove(p_file)
                 except Exception as e:
                     log.info(str(e))
                     log.info("Ocurrio un error al borrar el archivo: " + file)
@@ -360,7 +367,9 @@ def download_file_sftp(filename:StrOrPathList,
                 raise Exception("Destino erroneo.")
             
             if type(filename) is list:
-                lista_archivos = []
+                
+                lista_archivos: List[PurePosixPath] = []
+                
                 for i in filename:
                     try:
                         lista_archivos.append(PurePosixPath(i))
@@ -369,19 +378,19 @@ def download_file_sftp(filename:StrOrPathList,
                 
                 for file in lista_archivos:
                     
-                    dir_remoto = PurePosixPath(file).parent
+                    dir_remoto = file.parent.as_posix()
                     
                     log.debug("Ubicandose en ruta: " + str(dir_remoto))
                     server.chdir(dir_remoto)
                     
-                    destine = destine_path / str(file.name)
-                    log.debug("Obteniendo archivo: " + str(PurePosixPath(file)))
+                    destine = destine_path / file.name
+                    log.debug("Obteniendo archivo: " + str(file))
                     log.debug("Ruta Destino: " + str(destine))
                     
-                    server.get( PurePosixPath(file), destine )
+                    server.get( file.name, str(destine) )
                     
                     if flag_remove:
-                        server.remove(PurePosixPath(file))
+                        server.remove(file.name)
             else:
                 
                 try:
@@ -389,9 +398,9 @@ def download_file_sftp(filename:StrOrPathList,
                 except:
                     raise Exception("Origen erroneo.")
                 
-                dir_remoto = filename.parent
+                dir_remoto = filename.parent.as_posix()
                 
-                log.debug("Ubicandose en ruta: " + str(dir_remoto))
+                log.debug("Ubicandose en ruta: " + dir_remoto)
                 server.chdir(dir_remoto)
                 dir_list = server.listdir()
                 
@@ -406,15 +415,15 @@ def download_file_sftp(filename:StrOrPathList,
                     
                     if fnmatch.fnmatch(file, filename.name):
                         flag_exists = True
-                        filename_remoto = dir_remoto / file
-                        log.debug("Obteniendo archivo: " + str(filename_remoto))
+                        filename_remoto = (filename.parent / file).as_posix()
+                        log.debug("Obteniendo archivo: " + filename_remoto)
 
-                        log.debug("Ruta Destino: " + destine_path)
                         destine = destine_path / file
-                        server.get(file, destine)
+                        log.debug("Guardando en: " + str(destine))
+                        server.get(file, str(destine))
                         
                         if flag_remove:
-                            server.remove(filename)
+                            server.remove(file)
                             
                 if not flag_exists:
                     raise Exception("No se encontró coincidencias para: " + 
@@ -463,7 +472,7 @@ def download_by_prefix_sftp(sftpPath:StrOrPath,
             except:
                 raise Exception("Destino erroneo")
             
-            server.chdir(sftpPath)
+            server.chdir(sftpPath.as_posix())
             filelist = server.listdir()
             log.debug ("Lista SFTP: "+ str(len(filelist)))
             
@@ -473,7 +482,7 @@ def download_by_prefix_sftp(sftpPath:StrOrPath,
                 if prefix in filename:
                     log.debug("Obteniendo archivo: " + str(sftpPath / filename))
                     log.debug("Ruta Destino: " + str(path_file))
-                    server.get(filename, path_file)
+                    server.get(filename, str(path_file))
 
                     if flag_remove:
                         if path_file.exists:
